==> Gbook-0.8.tar.gz: Gbook/action.updateoptions.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

if( !$this->CheckPermission('Modify Site Preferences') )
{
	echo $this->ShowErrors(lang('needpermissionto', 'Modify Site Preferences'));
	return;
}

$this->SetPreference('send_notifications_to', trim($params['send_notifications_to']));
//$this->SetPreference('not_send_spamnotifications', isset($params['not_send_spamnotifications']) ? $params['not_send_spamnotifications'] : 0);

if ( is_numeric($params['max_spamrate_active']) && abs($params['max_spamrate_active']) <= 1 )
	$this->SetPreference('max_spamrate_active', abs($params['max_spamrate_active']));

if ( is_numeric($params['max_spamrate_notify']) && abs($params['max_spamrate_notify']) <= 1 )
	$this->SetPreference('max_spamrate_notify', abs($params['max_spamrate_notify']));

if ( is_numeric($params['max_spamrate_save']) && abs($params['max_spamrate_save']) <= 1 )
	$this->SetPreference('max_spamrate_save', abs($params['max_spamrate_save']));

$params = array('tab_message'=> 'optionsupdated', 'active_tab' => 'options');
$this->Redirect($id, 'defaultadmin', '', $params);
?>

==> Gbook-1.0.1.tar.gz: Gbook/action.updateoptions.php <==
<?php
#-------------------------------------------------------------------------
# Module: Gbook
# Author: Jos (josvd@live.nl)
#-------------------------------------------------------------------------
# CMS - CMS Made Simple is (c) 2008 by Ted Kulp (wishy@cmsmadesimple.org)
# This project's homepage is: http://www.cmsmadesimple.org
# The module's homepage is: http://dev.cmsmadesimple.org/projects/gbook/
#-------------------------------------------------------------------------

if (!isset($gCms)) exit;

if( !$this->CheckPermission('Modify Site Preferences') )
{
	echo $this->ShowErrors(lang('needpermissionto', 'Modify Site Preferences'));
	return;
}

$this->SetPreference('send_notifications_to', trim($params['send_notifications_to']));
//$this->SetPreference('not_send_spamnotifications', isset($params['not_send_spamnotifications']) ? $params['not_send_spamnotifications'] : 0);

if ( is_numeric($params['max_spamrate_active']) && abs($params['max_spamrate_active']) <= 1 )
	$this->SetPreference('max_spamrate_active', abs($params['max_spamrate_active']));

if ( is_numeric($params['max_spamrate_notify']) && abs($params['max_spamrate_notify']) <= 1 )
	$this->SetPreference('max_spamrate_notify', abs($params['max_spamrate_notify']));

if ( is_numeric($params['max_spamrate_save']) && abs($params['max_spamrate_save']) <= 1 )
	$this->SetPreference('max_spamrate_save', abs($params['max_spamrate_save']));

$params['badwords'] = str_replace(', ', ',', $params['badwords']);
$params['badwords'] = str_replace(' ,', ',', $params['badwords']);
$this->SetPreference('badwords', trim($params['badwords']));

$params = array('tab_message'=> 'optionsupdated', 'active_tab' => 'options');
$this->Redirect($id, 'defaultadmin', '', $params);
?>
